@@ -1,12 +1,14 @@
 /*
  * Generic ABC parser.
  *
- * Copyright (C) 1998-2018 Jean-François Moine
- * Adapted from abc2ps, Copyright (C) 1996, 1997 Michael Methfessel
+ * This file is part of abcm2ps.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * Copyright (C) 1998-2019 Jean-François Moine (http://moinejf.free.fr)
+ * Adapted from abc2ps, Copyright (C) 1996-1998 Michael Methfessel
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published
+ * by the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  */
 
@@ -409,7 +411,7 @@ static char *get_deco(char *p,
 static char *parse_acc(char *p,
 			struct SYMBOL *s)
 {
-	int pit, acc;
+	int pit = 0, acc;
 	unsigned nacc;
 
 	nacc = 0;
@@ -557,7 +559,7 @@ static void parse_clef(struct SYMBOL *s,
 	}
 
 	if (middle) {
-		int pit, acc, l;
+		int pit = 0, acc, l;
 		static const char line_tb[7] =
 			{ALTO, TREBLE, ALTO, BASS, ALTO, BASS, ALTO};
 
@@ -2297,7 +2299,7 @@ static char *parse_note(char *p,
 {
 	struct SYMBOL *s;
 	char *q;
-	int pit, len, acc, nostem, chord, j, m, n;
+	int pit = 0, len, acc, nostem, chord, j, m, n;
 
 	if (flags & ABC_F_GRACE) {	/* in a grace note sequence */
 		s = abc_new(ABC_T_NOTE, NULL);
