@@ -3,11 +3,11 @@
  *
  * This file is part of abcm2ps.
  *
- * Copyright (C) 2000-2017, Jean-François Moine.
+ * Copyright (C) 2000-2019 Jean-François Moine (http://moinejf.free.fr)
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published
+ * by the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  */
 
@@ -592,6 +592,21 @@ static void d_trill(struct deco_elt *de)
 		return;
 	s2 = de->s;
 
+	// only one ottava per staff
+	if (s2->sflags & S_OTTAVA) {
+		struct deco_elt *de2;
+
+		for (de2 = de->next; de2; de2 = de2->next) {
+			if (de2->t == de->t
+			 && de2->s->time == s2->time
+			 && de2->s->staff == s2->staff) {
+				de2->s->sflags &= ~S_OTTAVA;
+				de2->t = 0;
+			}
+		}
+		s2->sflags &= ~S_OTTAVA;
+	}
+
 //	if (de->start) {		/* deco start */
 		s = de->start->s;
 		x = s->x;
@@ -673,7 +688,7 @@ static void d_upstaff(struct deco_elt *de)
 	float x, yc, stafft, staffb, w;
 	int up, inv;
 
-	// don't treat here the long decorations
+	// don't treat here the start of long decorations
 	if (de->flags & DE_LDST)
 		return;
 	if (de->start) {
@@ -1146,6 +1161,7 @@ void deco_cnv(struct decos *dc,
 					 || dd->name[2] == 'b')
 						curvoice->ottava = 0;
 				}
+				s->sflags |= S_OTTAVA;
 			}
 			continue;
 		case 32:		/* invisible */
